@@ -14,7 +14,7 @@ G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
 #define SOUP_MINOR_VERSION (74)
-#define SOUP_MICRO_VERSION (0)
+#define SOUP_MICRO_VERSION (3)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -33,7 +33,7 @@ G_BEGIN_DECLS
 #  ifdef G_PLATFORM_WIN32
 #    ifdef LIBSOUP_COMPILATION
 #      ifdef DLL_EXPORT
-#        define SOUP_VAR __declspec(dllexport)
+#        define SOUP_VAR extern __declspec(dllexport)
 #      else /* !DLL_EXPORT */
 #        define SOUP_VAR extern
 #      endif /* !DLL_EXPORT */
